@@ -9,8 +9,6 @@ Driver for FortiGate
 from netcontrol.ssh.ssh import Ssh
 import logging as log
 import re
-import json
-
 
 class Fortigate(object):
     """
@@ -147,7 +145,7 @@ class Fortigate(object):
         if not self.ssh.connected:
             self.ssh.connect()
 
-        self.run_op_mode_command("diagnose ipsec ike status\n")
+        self.run_op_mode_command("diagnose vpn ike status\n")
         # FGT-B1-1 #  diagnose vpn ike status
         #connection: 3/348
         #IKE SA: created 3/348  established 3/3  times 0/2083/3220 ms
@@ -266,6 +264,7 @@ class Fortigate(object):
         log.info("Enter")
         result = {'members': {}, 'mode':''}
         members_flag = False         
+        mode = ''
 
         if not self.ssh.connected:
             self.ssh.connect()
@@ -294,6 +293,17 @@ class Fortigate(object):
                     result['members'][order]['seq_num'] = seq
                     result['members'][order]['status'] = status 
 
+                    # If sla mode, get sla value
+                    if mode == 'sla':
+                        log.debug("sla mode, get sla value")
+                        match_sla_value = re.search("(?:,\ssla\()(?P<sla>0x[0-9a-z]+)(?:\),)",line)
+                        if match_sla_value:
+                            sla = match_sla_value.group('sla')
+                            log.debug("Found sla={}".format(sla))
+                            result['members'][order]['sla'] = sla
+                        else:
+                            log.error("Could not extract sla value from member")
+
             # Get members
             match_member_section = re.search("\s\sMembers:",line)
             if match_member_section:
@@ -487,8 +497,6 @@ class Fortigate(object):
                 total = match_total_session.group('total')
                 result['total'] = total
 
-                log.debug("src={} sport={} dest={}".format(src, sport, dest))
-                
         log.debug("result={}".format(result))
         return result
 
